@@ -32,11 +32,13 @@
 class WordCompletion::WordCompletionPrivate
 {
     friend class WordCompletion;
+
 public:
     WordCompletionPrivate()
-        :blockCurrentListSignal(false),
-          wordsToSave(false)
-    {}
+        : blockCurrentListSignal(false)
+        , wordsToSave(false)
+    {
+    }
 
 private:
     typedef QMap<QString, int> WordMap;
@@ -55,7 +57,8 @@ private:
     bool wordsToSave;
 };
 
-WordCompletion::WordCompletion() : KCompletion()
+WordCompletion::WordCompletion()
+    : KCompletion()
 {
     d = new WordCompletionPrivate();
     configure();
@@ -108,8 +111,7 @@ QStringList WordCompletion::wordLists()
 QStringList WordCompletion::wordLists(const QString &language)
 {
     QStringList result;
-    for (QStringList::const_iterator it = d->dictionaries.constBegin();
-         it != d->dictionaries.constEnd(); ++it)
+    for (QStringList::const_iterator it = d->dictionaries.constBegin(); it != d->dictionaries.constEnd(); ++it)
         if (d->dictDetails[*it].language == language)
             result += *it;
     return result;
@@ -130,7 +132,7 @@ QString WordCompletion::currentWordList()
 
 bool WordCompletion::isConfigured()
 {
-    bool result = KSharedConfig::openConfig()->hasGroup("Dictionary 0");
+    bool result = KSharedConfig::openConfig()->hasGroup(QLatin1String("Dictionary 0"));
 
     return result;
 }
@@ -174,7 +176,8 @@ bool WordCompletion::setWordList(const QString &wordlist)
     if (result)
         d->current = wordlist;
     else {
-        if (d->dictionaries.isEmpty()) return false;
+        if (d->dictionaries.isEmpty())
+            return false;
         d->current = d->dictionaries[0];
     }
 
@@ -183,9 +186,7 @@ bool WordCompletion::setWordList(const QString &wordlist)
     QFile file(dictionaryFile);
     if (file.exists() && file.open(QIODevice::ReadOnly)) {
         QTextStream stream(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        stream.setCodec("UTF-8");
-#endif
+        stream.setEncoding(QStringConverter::Utf8);
         if (!stream.atEnd()) {
             if (stream.readLine() == QLatin1String("WPDictFile")) {
                 while (!stream.atEnd()) {
@@ -195,7 +196,7 @@ bool WordCompletion::setWordList(const QString &wordlist)
                         bool ok;
                         int weight = list[1].toInt(&ok);
                         if (ok && (weight > 0))
-                            d->map [list[0]] = weight;
+                            d->map[list[0]] = weight;
                     }
                 }
             }
@@ -242,9 +243,7 @@ void WordCompletion::save()
             return;
 
         QTextStream stream(&file);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        stream.setCodec("UTF-8");
-#endif
+        stream.setEncoding(QStringConverter::Utf8);
         stream << "WPDictFile\n";
         QMap<QString, int>::ConstIterator it;
         for (it = d->map.constBegin(); it != d->map.constEnd(); ++it) {
@@ -258,4 +257,3 @@ void WordCompletion::save()
         d->wordsToSave = false;
     }
 }
-
